#include "templates.hpp"
#include "config.hpp"   
#include "utils/directories.hpp"
#include <filesystem>
#include <iostream>
#include <vector>
#include <string>
#include <algorithm>
#include <iomanip>

namespace dropshell {

template_manager::template_manager() {
    // Constructor implementation
}

template_manager::~template_manager() {
    // Destructor implementation
}

bool template_manager::get_templates(std::vector<template_info>& templates) {
    templates.clear();
        
    // Helper function to add templates from a directory
    auto add_templates_from_dir = [&templates](const std::string& dir_path) {
        if (!std::filesystem::exists(dir_path)) {
            return;
        }
        
        for (const auto& entry : std::filesystem::directory_iterator(dir_path)) {
            if (entry.is_directory()) {
                template_info info;
                info.name = entry.path().filename().string();
                info.path = entry.path().string();
                
                // Check if template with same name already exists
                auto it = std::find_if(templates.begin(), templates.end(),
                    [&info](const template_info& t) { return t.name == info.name; });
                
                if (it == templates.end()) {
                    templates.push_back(info);
                }
            }
        }
    };
    
    add_templates_from_dir(get_local_config_templates_path());
    add_templates_from_dir(get_local_system_templates_path());    
    
    return true;
}

bool template_manager::get_template_info(const std::string& name, template_info& info) {
    std::vector<template_info> templates;
    if (!get_templates(templates)) {
        return false;
    }
    
    auto it = std::find_if(templates.begin(), templates.end(),
        [&name](const template_info& t) { return t.name == name; });
    
    if (it != templates.end()) {
        info = *it;
        return true;
    }
    
    return false;
}



void list_templates() {
    template_manager tm;
    std::vector<template_info> templates;
    
    if (!tm.get_templates(templates)) {
        std::cerr << "Error: Failed to get templates" << std::endl;
        return;
    }
    
    if (templates.empty()) {
        std::cout << "No templates found." << std::endl;
        return;
    }
    
    std::cout << "Available templates:" << std::endl;
    std::cout << std::left << std::setw(20) << "Name" << "Path" << std::endl;
    std::cout << std::string(60, '-') << std::endl;
    
    for (const auto& t : templates) {
        std::cout << std::left << std::setw(20) << t.name << t.path << std::endl;
    }
} 

} // namespace dropshell