#ifndef DIRECTORIES_HPP
#define DIRECTORIES_HPP

#include <string>

namespace dropshell {

    // local paths - return empty string on failure
    std::string get_local_dropshell_config_path();
    std::string get_local_system_templates_path();
    std::string get_local_config_path();
    std::string get_local_config_templates_path();
    std::string get_local_config_servers_path();
    std::string get_local_config_backups_path();

    std::string get_local_server_path(const std::string &server_name);
    std::string get_local_server_env_path(const std::string &server_name);

    std::string get_local_service_path(const std::string &server_name, const std::string &service_name);
    std::string get_local_service_env_path(const std::string &server_name, const std::string &service_name);

    // remote paths
    // DROPSHELL_DIR
    //   |-- service name
    //      |-- config
    //          |-- service.env
    //          |-- (user config files)
    //      |-- template
    //          |-- (script files)
    //      |-- backups
    std::string get_remote_DROPSHELL_path(const std::string &server_name);
    std::string get_remote_service_path(const std::string &server_name, const std::string &service_name);
    std::string get_remote_service_config_path(const std::string &server_name, const std::string &service_name);
    std::string get_remote_service_template_path(const std::string &server_name, const std::string &service_name);
    std::string get_remote_service_backups_path(const std::string &server_name, const std::string &service_name);

    std::string get_remote_service_env_file(const std::string &server_name, const std::string &service_name);
} // namespace dropshell

#endif
